PubIoPackage class

Pub io package

Constructors

PubIoPackage(String path, {PubIoPackageOptions? options})
Pub io package

Properties

dof → String
Dart or flutter
no setter
dofPub → String
Dart pub of flutter pub (handles workspace)
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasWorkspaceResolution → bool
True if it has workspace resolution
no setter
isFlutter ↔ bool
True for flutter project
latefinal
isWorkspace → bool
True for workspace
no setter
options → PubIoPackageOptions
Options
final
path → String
Path
final
pubspecYaml ↔ Map<String, Object?>
Ok when ready
getter/setter pair
ready → Future<Null>
Ready (pubspec.yaml loaded)
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shell ↔ Shell
Shell
getter/setter pair
shellEnvironment → ShellEnvironment
shell environment
no setter
versionOrNull → Version?
Get the package Version (or null) from pubspec.yaml
no setter

Methods

cachedOrGetPackageConfigMap() → Future<Map<String, Object?>>
Cached or get package config map
checkFormat() → Future<void>
Check the format, throws if some files need formatting.
dumpDeps() → Future<void>
List dependencies
format() → Future<void>
Format the code (dart format)
getFilteredDartDirs() → Future<List<String>>
Top level dart dirs (cached)
getResolvedDependencies() → Future<List<String>>
Get resolved dependency list
getResolvedPackagePath(String package) → Future<String?>
Get resolved package path
getWorkspaceRootPath() → Future<String>
Get the workspace root path (only if isWorkspace or hasWorkspaceResolution)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pubDowngrade({bool? offline}) → Future<void>
Pub downgrade
pubGet({bool? offline}) → Future<void>
Pub get
pubUpgrade({bool? offline}) → Future<void>
Pub upgrade
readPackageConfigMap() → Future<Map<String, Object?>>
Read and cache package config map
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited