package library

Classes

DartPackage
Dart package.
DartPackageIo
Io base implementation.
DartPackageIoCompiledExe
Compile exe info
DartPackageReader
Dart package reader.
FilterDartProjectOptions
Filter dart project options
PackageRunCiOptions
Package run options
PubGlobalGitPackage
Global package from git.
PubGlobalGitPackageInstall
Global package from git for installation.
PubGlobalHostedPackage
pub.dartlang.org hosted package
PubGlobalHostedPackageInstall
Hosted package with install constraint
PubGlobalPackage
Global package definition.
PubGlobalPackageService
Service to manage pub global packages
PubGlobalPathPackage
Global package from path.
PubGlobalPathPackageInstall
Global package from git for installation.
Version
A parsed semantic version number.
VersionBoundaries
Version boundaries.
VersionBoundary
Version boundary.
VersionConstraint
A VersionConstraint is a predicate that can determine whether a given version is valid or not.
VersionRange
Constrains versions to a fall within a given range.
VersionUnion
A version constraint representing a union of multiple disjoint version ranges.

Extensions

DartPackageIoCompileExeExt on DartPackageIo
DartPackageIoExt on DartPackageIo
Io base implementation.
DartPackageReaderExt on DartPackageReader
Dart package reader extension.
DartPackageWriterExt on DartPackage
Dart package.
FilterDartProjectOptionsExt on FilterDartProjectOptions
Filter dart project options extension.

Functions

checkOrPubActivateHostedPackage(String name, {bool? verbose, VersionBoundaries? versionBoundaries}) Future<void>
Check or
ioPackageRunCi(String path) Future<void>
Kept for compatibility
packageRunCi(String path, {PackageRunCiOptions? options, bool? recursive, bool? noFormat, bool? noAnalyze, bool? noTest, bool? noBuild, bool? noPubGet, bool? verbose, bool? pubUpgrade, int? poolSize}) Future<void>
Run basic tests on dart/flutter package
recursivePackagesRun(List<String> paths, {required FutureOr action(String package), bool? verbose, int? poolSize, List<String>? dependencies, FilterDartProjectOptions? filterDartProjectOptions}) Future<void>
Each path is tested
recursivePubPath(List<String> dirs, {List<String>? dependencies, bool? readConfig, FilterDartProjectOptions? filterDartProjectOptions}) Future<List<String>>
if forceRecursive is true, we folder going deeper even if the current path is a dart project
runCiInitPubWorkspacesCache() → void
Internal only use for run_ci binary for now