FilterDartProjectOptions class

Filter dart project options

Available extensions

Constructors

FilterDartProjectOptions({bool? ignoreSdkConstraints, VersionBoundaries? minSdk, VersionBoundaries? maxSdk})
Create filter options.

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreSdkConstraints → bool?
Ignore sdk constraints (default to false)
final
maxSdk → VersionBoundaries?
Constraint on maxSdk.
final
minSdk → VersionBoundaries?
Constraint on minSdk.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

hasConstraintsOverride() → bool

Available on FilterDartProjectOptions, provided by the FilterDartProjectOptionsExt extension

True if there is a constraint.
matchesBoundaries(VersionBoundaries? boundaries) → bool

Available on FilterDartProjectOptions, provided by the FilterDartProjectOptionsExt extension

Return true if the sdk constraints are ignored
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited