PackageRunCiOptions class

Package run options

Constructors

PackageRunCiOptions({bool formatOnly = false, bool testOnly = false, bool buildOnly = false, bool analyzeOnly = false, bool pubGetOnly = false, bool verbose = false, bool recursive = false, bool pubUpgradeOnly = false, bool pubDowngradeOnly = false, bool fixOnly = false, bool noNodeTest = false, bool noVmTest = false, bool vmTestOnly = false, bool noBrowserTest = false, bool chromeJsTestOnly = false, bool noTest = false, bool noAnalyze = false, bool noFormat = false, bool noPubGet = false, bool noBuild = false, bool offline = false, bool noNpmInstall = false, int? poolSize, bool noOverride = false, bool dryRun = false, bool prjInfo = false, bool noRunCi = false, bool ignoreErrors = false, FilterDartProjectOptions? filterDartProjectOptions, bool printPath = false})
Package run ci options.

Properties

analyzeOnly → bool
Only run analyze.
final
buildOnly → bool
Only run build.
final
chromeJsTestOnly → bool
Only run chrome dart2js test
final
dryRun → bool
Dry run (no execution)
final
filterDartProjectOptions → FilterDartProjectOptions?
Ignore sdk constraints
final
fixOnly → bool
Only run fix.
final
formatOnly → bool
Only run format.
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreErrors → bool
Ignore shell errors.
final
noAnalyze ↔ bool
Do not run analyze.
getter/setter pair
noBrowserTest → bool
Do not run browser tests.
final
noBuild ↔ bool
Do not build.
getter/setter pair
noFormat ↔ bool
Do not run format.
getter/setter pair
noNodeTest → bool
Do not run node tests.
final
noNpmInstall → bool
Do not run npm install.
final
noOverride → bool
Do not run run_ci_override.dart, typically to use in this file
final
noPubGet → bool
Do not run pub get.
final
noPubGetOrUpgrade → bool
True if no pub get or upgrade
no setter
noRunCi → bool
No actions are performed, only project info if specified.
final
noTest ↔ bool
Do not run any tests.
getter/setter pair
noVmTest → bool
Do not run vm tests.
final
offline → bool
Run in offline mode.
final
poolSize → int?
Pool size
final
printPath → bool
Just print the path
final
prjInfo → bool
Extra project info displayed
final
pubDowngradeOnly → bool
Only run pub downgrade.
final
pubGetOnly → bool
Only run pub get.
final
pubUpgradeOnly → bool
Only run pub upgrade.
final
recursive → bool
Only run the specified folder.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testOnly → bool
Only run test.
final
verbose → bool
Run in verbose mode.
final
vmTestOnly → bool
Only run vm test
final

Methods

clone() → PackageRunCiOptions
Clone the options
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited