PubGlobalGitPackageInstall class

Global package from git for installation.

Inheritance
Implemented types

Constructors

PubGlobalGitPackageInstall(String name, {Version? version, required String gitUrl, String? gitPath, String? gitRef})
Global package from git.

Properties

activateArgs List<String>
pub global activate arguments
no setter
gitPath String?
Git path
final
gitRef String?
Git ref
final
gitUrl String
Git url
final
hashCode int
The hash code for this object.
no setterinherited
name String
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
Package source.
no setterinherited
sourceType String
Source type (git, path)
no setteroverride
version Version?
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited