PubGlobalHostedPackage class

pub.dartlang.org hosted package

Implemented types
Implementers

Constructors

PubGlobalHostedPackage(String name, {Version? version})
Hosted package

Properties

activateArgs List<String>
pub global activate arguments
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
latefinalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version Version?
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited