PubGlobalHostedPackageInstall class
Hosted package with install constraint
- Implemented types
Constructors
- PubGlobalHostedPackageInstall(String name, {VersionBoundaries? versionBoundaries})
- Hosted package
Properties
-
activateArgs
→ List<
String> -
pub global activateargumentsno setteroverride - hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version ↔ Version?
-
latefinalinherited
- versionBoundaries → VersionBoundaries?
-
For installation
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited