PubGlobalPackageService class

Service to manage pub global packages

Constructors

PubGlobalPackageService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

activateGlobalPackage(PubGlobalPackage package, {bool? dryRun, bool? verbose}) Future<void>
Activate package according its saved configuration if any
checkOrActivateHostedPackage(PubGlobalHostedPackageInstall package, {bool? verbose}) Future<void>
Check package version
deactivateGlobalPackage(String name, {bool? dryRun, bool? verbose}) Future<void>
Deactivate package
getActivatedPackage(String name, {bool? verbose}) Future<PubGlobalPackage?>
Get activated package information if any
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited