PubGlobalPathPackage class
Global package from path.
- Implemented types
- Implementers
Constructors
- PubGlobalPathPackage(String name, {Version? version})
- Global package from path.
Properties
-
activateArgs
→ List<
String> -
pub global activateargumentsno setterinherited - hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
latefinalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
Package source.
no setterinherited
- sourceType → String
-
Source type (git, path)
no setter
- version ↔ Version?
-
latefinalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited