PubGlobalPathPackageInstall class

Global package from git for installation.

Inheritance
Implemented types

Constructors

PubGlobalPathPackageInstall(String name, {Version? version, required String path})
Global package from git.

Properties

activateArgs List<String>
pub global activate arguments
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
name String
latefinalinherited
path String
Source path
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
Package source.
no setterinherited
sourceType String
Source type (git, path)
no setterinherited
version Version?
latefinalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited