userShellAliasEnabled top-level property

bool userShellAliasEnabled
getter/setter pair

Whether the user shell alias fallback is used.

Only enabled on Linux and macOS for now. Can be set to false to turn the feature off (or to true on another platform at your own risk).

Implementation

var userShellAliasEnabled = Platform.isLinux || Platform.isMacOS;