IteratePubPathOptions class
Options for iteratePubPath.
Constructors
-
IteratePubPathOptions({List<
String> ? dependencies, bool? recursive, bool? readConfig, FilterDartProjectOptions? filterDartProjectOptions}) -
Create iterate options.
const
Properties
-
dependencies
→ List<
String> ? -
if specified, only the projects that contain such dependency are
iterated, use either a dependency like
path, or 'direct:path', 'dev:path' or 'override:path'.final - filterDartProjectOptions → FilterDartProjectOptions?
-
Dart project filter (sdk constraints).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- readConfig → bool?
-
If true, the package config file is read to also match transitive
dependencies.
final
- recursive → bool?
-
Iterate the sub directories (default true), when false only
dirsthemselves are tested.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited