PubGlobalPackage class abstract
Global package definition.
Constructors
Properties
-
activateArgs
→ List<
String> -
pub global activateargumentsno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Package name.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → Version?
-
Package version.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromActivatedLine(
String line, String packageName) → PubGlobalPackage? - Get global package from actived line.
-
fromListLine(
String line) → PubGlobalPackage? - return null if it cannot be parsed