SinglePackageCiRunner class
CiRunner helper
Constructors
- SinglePackageCiRunner(PubIoPackage _pubIoPackage, PackageRunCiOptions options)
- CiRunner
Properties
-
filteredDartDirs
↔ List<
String> ? -
Filtered dart dirs
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFlutterPackage → bool
-
True for flutter package
no setter
- isWorkspaceRoot → bool
-
True for workspace root
no setter
- options → PackageRunCiOptions
-
Options
final
- path → String
-
Path
no setter
- pubspecSdkBoundaries → VersionBoundaries?
-
Pubspec sdk boundaries
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shell → Shell
-
Shell
latefinal
Methods
-
analyze(
) → Future< void> - Analyze
-
fix(
) → Future< void> - Fix basic issues
-
format(
{bool fix = false}) → Future< void> - Check or fix format
-
init(
) → Future< void> - Init pubspec map
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runScript(
String script) → Future< List< ProcessResult> > - Run a script
-
runTest(
{List< String> ? testOptions}) → Future<void> - Run tests
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited