recursivePubPath function
if forceRecursive is true, we folder going deeper even if the current
path is a dart project
if ignoreSdkConstraints is true, it lists the project even if not compatible.
if dependencies is specified, it will only list the project that contains
such dependency, use either dependency like path, or 'direct:path', 'dev:path' or 'override:path'.
Hidden folders, build, deploy, node_modules and the test folder of
a project are not scanned.
Returns the list of valid pub folder, including me
Implementation
Future<List<String>> recursivePubPath(
List<String> dirs, {
List<String>? dependencies,
bool? readConfig,
FilterDartProjectOptions? filterDartProjectOptions,
}) => scanPubPath(
dirs,
options: IteratePubPathOptions(
dependencies: dependencies,
readConfig: readConfig,
filterDartProjectOptions: filterDartProjectOptions,
),
);